==> zio-aws-iotroborunner_2.13-5.19.7.3-sources.jar: zio/aws/iotroborunner/model/package.scala <==
package zio.aws.iotroborunner
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.iotroborunner.model.primitives.WorkerAdditionalFixedPropertiesJson.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object CreatedAtTimestamp extends Subtype[Instant]
    type CreatedAtTimestamp =
      zio.aws.iotroborunner.model.primitives.CreatedAtTimestamp.Type
    object DestinationAdditionalFixedProperties extends Subtype[String]
    type DestinationAdditionalFixedProperties =
      zio.aws.iotroborunner.model.primitives.DestinationAdditionalFixedProperties.Type
    object DestinationArn extends Subtype[String]
    type DestinationArn =
      zio.aws.iotroborunner.model.primitives.DestinationArn.Type
    object DestinationGenericIdentifier extends Subtype[String]
    type DestinationGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.DestinationGenericIdentifier.Type
    object DestinationId extends Subtype[String]
    type DestinationId =
      zio.aws.iotroborunner.model.primitives.DestinationId.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.iotroborunner.model.primitives.IdempotencyToken.Type
    object ListSitesPageSize extends Subtype[Int]
    type ListSitesPageSize =
      zio.aws.iotroborunner.model.primitives.ListSitesPageSize.Type
    object ListWorkerFleetsPageSize extends Subtype[Int]
    type ListWorkerFleetsPageSize =
      zio.aws.iotroborunner.model.primitives.ListWorkerFleetsPageSize.Type
    object ListWorkersPageSize extends Subtype[Int]
    type ListWorkersPageSize =
      zio.aws.iotroborunner.model.primitives.ListWorkersPageSize.Type
    object Name extends Subtype[String]
    type Name = zio.aws.iotroborunner.model.primitives.Name.Type
    object OrientationDegreesDouble extends Subtype[Double]
    type OrientationDegreesDouble =
      zio.aws.iotroborunner.model.primitives.OrientationDegreesDouble.Type
    object PageSize extends Subtype[Int]
    type PageSize = zio.aws.iotroborunner.model.primitives.PageSize.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.iotroborunner.model.primitives.PaginationToken.Type
    object SiteArn extends Subtype[String]
    type SiteArn = zio.aws.iotroborunner.model.primitives.SiteArn.Type
    object SiteCountryCode extends Subtype[String]
    type SiteCountryCode =
      zio.aws.iotroborunner.model.primitives.SiteCountryCode.Type
    object SiteDescription extends Subtype[String]
    type SiteDescription =
      zio.aws.iotroborunner.model.primitives.SiteDescription.Type
    object SiteGenericIdentifier extends Subtype[String]
    type SiteGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.SiteGenericIdentifier.Type
    object SiteId extends Subtype[String]
    type SiteId = zio.aws.iotroborunner.model.primitives.SiteId.Type
    object UpdatedAtTimestamp extends Subtype[Instant]
    type UpdatedAtTimestamp =
      zio.aws.iotroborunner.model.primitives.UpdatedAtTimestamp.Type
    object VendorAdditionalFixedPropertiesJson extends Subtype[String]
    type VendorAdditionalFixedPropertiesJson =
      zio.aws.iotroborunner.model.primitives.VendorAdditionalFixedPropertiesJson.Type
    object VendorAdditionalTransientPropertiesJson extends Subtype[String]
    type VendorAdditionalTransientPropertiesJson =
      zio.aws.iotroborunner.model.primitives.VendorAdditionalTransientPropertiesJson.Type
    object VendorWorkerId extends Subtype[String]
    type VendorWorkerId =
      zio.aws.iotroborunner.model.primitives.VendorWorkerId.Type
    object VendorWorkerIpAddress extends Subtype[String]
    type VendorWorkerIpAddress =
      zio.aws.iotroborunner.model.primitives.VendorWorkerIpAddress.Type
    object WorkerAdditionalFixedPropertiesJson extends Subtype[String]
    type WorkerAdditionalFixedPropertiesJson =
      zio.aws.iotroborunner.model.primitives.WorkerAdditionalFixedPropertiesJson.Type
    object WorkerAdditionalTransientPropertiesJson extends Subtype[String]
    type WorkerAdditionalTransientPropertiesJson =
      zio.aws.iotroborunner.model.primitives.WorkerAdditionalTransientPropertiesJson.Type
    object WorkerArn extends Subtype[String]
    type WorkerArn = zio.aws.iotroborunner.model.primitives.WorkerArn.Type
    object WorkerFleetAdditionalFixedProperties extends Subtype[String]
    type WorkerFleetAdditionalFixedProperties =
      zio.aws.iotroborunner.model.primitives.WorkerFleetAdditionalFixedProperties.Type
    object WorkerFleetArn extends Subtype[String]
    type WorkerFleetArn =
      zio.aws.iotroborunner.model.primitives.WorkerFleetArn.Type
    object WorkerFleetGenericIdentifier extends Subtype[String]
    type WorkerFleetGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.WorkerFleetGenericIdentifier.Type
    object WorkerFleetId extends Subtype[String]
    type WorkerFleetId =
      zio.aws.iotroborunner.model.primitives.WorkerFleetId.Type
    object WorkerGenericIdentifier extends Subtype[String]
    type WorkerGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.WorkerGenericIdentifier.Type
    object WorkerId extends Subtype[String]
    type WorkerId = zio.aws.iotroborunner.model.primitives.WorkerId.Type
  }
  type Destinations = List[zio.aws.iotroborunner.model.Destination]
  type Sites = List[zio.aws.iotroborunner.model.Site]
  type WorkerFleets = List[zio.aws.iotroborunner.model.WorkerFleet]
  type Workers = List[zio.aws.iotroborunner.model.Worker]
}

==> zio-aws-iotroborunner_3-6.20.97.2-sources.jar: zio/aws/iotroborunner/model/package.scala <==
package zio.aws.iotroborunner
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.iotroborunner.model.primitives.WorkerAdditionalFixedPropertiesJson.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object CreatedAtTimestamp extends Subtype[Instant]
    type CreatedAtTimestamp =
      zio.aws.iotroborunner.model.primitives.CreatedAtTimestamp.Type
    object DestinationAdditionalFixedProperties extends Subtype[String]
    type DestinationAdditionalFixedProperties =
      zio.aws.iotroborunner.model.primitives.DestinationAdditionalFixedProperties.Type
    object DestinationArn extends Subtype[String]
    type DestinationArn =
      zio.aws.iotroborunner.model.primitives.DestinationArn.Type
    object DestinationGenericIdentifier extends Subtype[String]
    type DestinationGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.DestinationGenericIdentifier.Type
    object DestinationId extends Subtype[String]
    type DestinationId =
      zio.aws.iotroborunner.model.primitives.DestinationId.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.iotroborunner.model.primitives.IdempotencyToken.Type
    object ListSitesPageSize extends Subtype[Int]
    type ListSitesPageSize =
      zio.aws.iotroborunner.model.primitives.ListSitesPageSize.Type
    object ListWorkerFleetsPageSize extends Subtype[Int]
    type ListWorkerFleetsPageSize =
      zio.aws.iotroborunner.model.primitives.ListWorkerFleetsPageSize.Type
    object ListWorkersPageSize extends Subtype[Int]
    type ListWorkersPageSize =
      zio.aws.iotroborunner.model.primitives.ListWorkersPageSize.Type
    object Name extends Subtype[String]
    type Name = zio.aws.iotroborunner.model.primitives.Name.Type
    object OrientationDegreesDouble extends Subtype[Double]
    type OrientationDegreesDouble =
      zio.aws.iotroborunner.model.primitives.OrientationDegreesDouble.Type
    object PageSize extends Subtype[Int]
    type PageSize = zio.aws.iotroborunner.model.primitives.PageSize.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.iotroborunner.model.primitives.PaginationToken.Type
    object SiteArn extends Subtype[String]
    type SiteArn = zio.aws.iotroborunner.model.primitives.SiteArn.Type
    object SiteCountryCode extends Subtype[String]
    type SiteCountryCode =
      zio.aws.iotroborunner.model.primitives.SiteCountryCode.Type
    object SiteDescription extends Subtype[String]
    type SiteDescription =
      zio.aws.iotroborunner.model.primitives.SiteDescription.Type
    object SiteGenericIdentifier extends Subtype[String]
    type SiteGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.SiteGenericIdentifier.Type
    object SiteId extends Subtype[String]
    type SiteId = zio.aws.iotroborunner.model.primitives.SiteId.Type
    object UpdatedAtTimestamp extends Subtype[Instant]
    type UpdatedAtTimestamp =
      zio.aws.iotroborunner.model.primitives.UpdatedAtTimestamp.Type
    object VendorAdditionalFixedPropertiesJson extends Subtype[String]
    type VendorAdditionalFixedPropertiesJson =
      zio.aws.iotroborunner.model.primitives.VendorAdditionalFixedPropertiesJson.Type
    object VendorAdditionalTransientPropertiesJson extends Subtype[String]
    type VendorAdditionalTransientPropertiesJson =
      zio.aws.iotroborunner.model.primitives.VendorAdditionalTransientPropertiesJson.Type
    object VendorWorkerId extends Subtype[String]
    type VendorWorkerId =
      zio.aws.iotroborunner.model.primitives.VendorWorkerId.Type
    object VendorWorkerIpAddress extends Subtype[String]
    type VendorWorkerIpAddress =
      zio.aws.iotroborunner.model.primitives.VendorWorkerIpAddress.Type
    object WorkerAdditionalFixedPropertiesJson extends Subtype[String]
    type WorkerAdditionalFixedPropertiesJson =
      zio.aws.iotroborunner.model.primitives.WorkerAdditionalFixedPropertiesJson.Type
    object WorkerAdditionalTransientPropertiesJson extends Subtype[String]
    type WorkerAdditionalTransientPropertiesJson =
      zio.aws.iotroborunner.model.primitives.WorkerAdditionalTransientPropertiesJson.Type
    object WorkerArn extends Subtype[String]
    type WorkerArn = zio.aws.iotroborunner.model.primitives.WorkerArn.Type
    object WorkerFleetAdditionalFixedProperties extends Subtype[String]
    type WorkerFleetAdditionalFixedProperties =
      zio.aws.iotroborunner.model.primitives.WorkerFleetAdditionalFixedProperties.Type
    object WorkerFleetArn extends Subtype[String]
    type WorkerFleetArn =
      zio.aws.iotroborunner.model.primitives.WorkerFleetArn.Type
    object WorkerFleetGenericIdentifier extends Subtype[String]
    type WorkerFleetGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.WorkerFleetGenericIdentifier.Type
    object WorkerFleetId extends Subtype[String]
    type WorkerFleetId =
      zio.aws.iotroborunner.model.primitives.WorkerFleetId.Type
    object WorkerGenericIdentifier extends Subtype[String]
    type WorkerGenericIdentifier =
      zio.aws.iotroborunner.model.primitives.WorkerGenericIdentifier.Type
    object WorkerId extends Subtype[String]
    type WorkerId = zio.aws.iotroborunner.model.primitives.WorkerId.Type
  }
  type Destinations = List[zio.aws.iotroborunner.model.Destination]
  type Sites = List[zio.aws.iotroborunner.model.Site]
  type WorkerFleets = List[zio.aws.iotroborunner.model.WorkerFleet]
  type Workers = List[zio.aws.iotroborunner.model.Worker]
}
